@@ -315,6 +315,7 @@ directories."
     ;; actual file name MUST end with ".el".  Use "git blame" for
     ;; more information.
     (setq notmuch-init-file                (etc "notmuch-init"))
+    (setq nov-save-place-file              (var "nov-save-place.el"))
     (setq org-gcal-dir                     (var "org/gcal/"))
     (eval-after-load 'org-caldav
       `(make-directory ,(var "org/caldav/save") t))
@@ -348,10 +349,10 @@ directories."
     (setq xkcd-cache-dir                   (var "xkcd/"))
     (eval-after-load 'yasnippet
       `(make-directory ,(etc "yasnippet/snippets/") t))
-    (setq yas-snippet-dirs                 (list (etc "yasnippet/snippets/")
-                                                 'yas-installed-snippets-dir))
+    (setq yas-snippet-dirs                 (list (etc "yasnippet/snippets/")))
     ))
 
+;;; _
 (provide 'no-littering)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
